@@ -44,8 +44,7 @@ void gd_ev_view_find_changed (EvView *view,
                               EvJobFind *job,
                               gint page);
 
-void gd_show_about_dialog (GtkWindow *parent,
-                           gboolean is_books);
+void gd_show_about_dialog (GtkWindow *parent);
 
 #endif /* __GD_UTILS_H__ */
                                   
