@@ -274,7 +274,7 @@ const EmptyResultsBox = new Lang.Class({
         if (this._mode == WindowMode.WindowMode.COLLECTIONS)
             text = _("No collections found");
         else
-            text = Application.application.isBooks ? _("No books found") : _("No documents found");
+            text = _("No documents found");
 
         this.add(new Gtk.Label({ label: '<b><span size="large">' + text + '</span></b>',
                                  use_markup: true,
@@ -288,19 +288,10 @@ const EmptyResultsBox = new Lang.Class({
         }
 
         if (this._mode == WindowMode.WindowMode.COLLECTIONS) {
-            let label;
-            if (Application.application.isBooks)
-                label = _("You can create collections from the Books view");
-            else
-                label = _("You can create collections from the Documents view");
-
-            this.add(new Gtk.Label({ label: label }));
+            this.add(new Gtk.Label({ label: _("You can create collections from the Documents view") }));
             return;
         }
 
-        if (Application.application.isBooks)
-            return;
-
         let documentsPath = GLib.get_user_special_dir(GLib.UserDirectory.DIRECTORY_DOCUMENTS);
         let detailsStr = _("Documents from your <a href=\"system-settings\">Online Accounts</a> and " +
                            "<a href=\"file://%s\">Documents folder</a> will appear here.").format(documentsPath);
@@ -633,6 +624,7 @@ const OverviewToolbar = new Lang.Class({
             customTitle = null;
             if (!this._collBackButton) {
                 this._collBackButton = this.addBackButton();
+                this.toolbar.child_set_property(this._collBackButton, "position", 0);
                 this._collBackButton.show();
             }
         } else {
@@ -665,13 +657,15 @@ const OverviewToolbar = new Lang.Class({
         this.toolbar.set_custom_title(this._stackSwitcher);
         this._checkCollectionWidgets();
 
+        this.addSearchButton('view.search');
+        this.addMenuButton();
+
         let selectionButton = new Gtk.Button({ image: new Gtk.Image ({ icon_name: 'object-select-symbolic' }),
                                                tooltip_text: _("Select Items"),
                                                action_name: 'view.selection-mode' });
         this.toolbar.pack_end(selectionButton);
 
         this._addViewMenuButton();
-        this.addSearchButton('view.search');
 
         // connect to active collection changes while in this mode
         this._collectionId =
@@ -1049,8 +1043,7 @@ var OverviewStack = new Lang.Class({
 
         // now create the actual content widgets
         this._documents = new ViewContainer(this, WindowMode.WindowMode.DOCUMENTS);
-        let label = Application.application.isBooks ? _('Books') : _("Documents");
-        this._stack.add_titled(this._documents, 'documents', label);
+        this._stack.add_titled(this._documents, 'documents', _("Documents"));
 
         this._collections = new ViewContainer(this, WindowMode.WindowMode.COLLECTIONS);
         this._stack.add_titled(this._collections, 'collections', _("Collections"));
